@@ -15,8 +15,8 @@ xfpm_shutdown_request_get_type (void)
 	{ XFPM_DO_NOTHING, "XFPM_DO_NOTHING", "do-nothing" },
 	{ XFPM_DO_SUSPEND, "XFPM_DO_SUSPEND", "do-suspend" },
 	{ XFPM_DO_HIBERNATE, "XFPM_DO_HIBERNATE", "do-hibernate" },
-	{ XFPM_DO_SHUTDOWN, "XFPM_DO_SHUTDOWN", "do-shutdown" },
 	{ XFPM_ASK, "XFPM_ASK", "ask" },
+	{ XFPM_DO_SHUTDOWN, "XFPM_DO_SHUTDOWN", "do-shutdown" },
 	{ 0, NULL, NULL }
 	};
 	type = g_enum_register_static ("XfpmShutdownRequest", values);
@@ -24,6 +24,22 @@ xfpm_shutdown_request_get_type (void)
 	return type;
 }
 GType
+xfpm_lid_trigger_action_get_type (void)
+{
+	static GType type = 0;
+	if (type == 0) {
+	static const GEnumValue values[] = {
+	{ LID_TRIGGER_NOTHING, "LID_TRIGGER_NOTHING", "nothing" },
+	{ LID_TRIGGER_SUSPEND, "LID_TRIGGER_SUSPEND", "suspend" },
+	{ LID_TRIGGER_HIBERNATE, "LID_TRIGGER_HIBERNATE", "hibernate" },
+	{ LID_TRIGGER_LOCK_SCREEN, "LID_TRIGGER_LOCK_SCREEN", "lock-screen" },
+	{ 0, NULL, NULL }
+	};
+	type = g_enum_register_static ("XfpmLidTriggerAction", values);
+  }
+	return type;
+}
+GType
 xfpm_battery_state_get_type (void)
 {
 	static GType type = 0;
@@ -61,6 +77,21 @@ xfpm_button_key_get_type (void)
   }
 	return type;
 }
+GType
+xfpm_show_icon_get_type (void)
+{
+	static GType type = 0;
+	if (type == 0) {
+	static const GEnumValue values[] = {
+	{ SHOW_ICON_ALWAYS, "SHOW_ICON_ALWAYS", "always" },
+	{ SHOW_ICON_WHEN_BATTERY_PRESENT, "SHOW_ICON_WHEN_BATTERY_PRESENT", "when-battery-present" },
+	{ SHOW_ICON_WHEN_BATTERY_CHARGING_DISCHARGING, "SHOW_ICON_WHEN_BATTERY_CHARGING_DISCHARGING", "when-battery-charging-discharging" },
+	{ 0, NULL, NULL }
+	};
+	type = g_enum_register_static ("XfpmShowIcon", values);
+  }
+	return type;
+}
 
 /* Generated data ends here */
 
